<p align="center">
  <a href=""><img src="https://github.com/yury-sannikov/chaosify/blob/main/resources/chaos-lib.png?raw=true" alt="Chaosify"></a>
</p>

<p align="center">
    <em>“In all chaos there is a cosmos, in all disorder a secret order.”</em><br/>
    ― Carl Gustav Jung
</p>


<p align="center">
    <em>Chaos Testing library to build better, resilient Python applications.</em>
</p>



<p align="center">
<a href="https://github.com/yury-sannikov/chaosify/actions/workflows/run_coverage.yml" target="_blank">
    <img src="https://github.com/yury-sannikov/chaosify/actions/workflows/run_coverage.yml/badge.svg" alt="Test">
</a>
<a href="https://pypi.org/project/chaosify" target="_blank">
    <img src="https://img.shields.io/pypi/v/chaosify?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://pypi.org/project/chaosify" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/chaosify.svg?color=%2334D058" alt="Supported Python versions">
</a>
</p>

---

**Documentation**: <a href="" target="_blank"></a>

**Source Code**: <a href="https://github.com/yury-sannikov/chaosify" target="_blank">https://github.com/yury-sannikov/chaosify</a>

---

Chaosify, is a powerful chaos testing library for Python applications. Designed to inject controlled chaos into your code.

Chaosify empowers developers to uncover weaknesses and improve the resilience of their software. Whether you're building microservices, distributed systems, or monolithic applications

Key features are:
* introduce latency injection
* emulate resource exhaustion
* mimic service disruptions

Chaosify is highly configurable, allowing you to fine-tune chaos parameters and observe how your system behaves under stress.
